Analyzer class

Constructors

Analyzer()

Properties

analysisCollection → AnalysisContextCollection
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkPath → String
no setter

Methods

analyze(List<String> paths) → Future<List<AnalyzeFileResult>>
Analyzes the given path and returns the resolved unit results.
dispose() → Future<void>
initialize({required String root}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited