Combinator class

Implemented types

Constructors

Combinator({required String? ignore, required String show})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
ignore → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
show → String
final

Methods

compareTo(Combinator other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override