Config class

Constructors

Config({List<String> exclude = const [], bool format = false})
Config.load(String path)
factory

Properties

exclude → List<String>
final
format → bool
When false, the import statements will not be formatted, leaving 1 import statement per line.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldExclude(String path) → bool
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited