MultiReference class

Implemented types
Mixed-in types

Constructors

MultiReference({required List<Reference> references})

Properties

associatedElement → Element?
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
hide → bool
Whether to hide the reference from the import statement
no setteroverride
hideCombinator → String?
no setteroverride
ignores → List<String>?
no setteroverride
import → Import
no setteroverride
lib → LibraryElement
no setteroverride
optional → bool
no setteroverride
prefix → String?
no setteroverride
references → List<Reference>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canInclude(ResolvedReferences import) → bool
override
canJoin(Reference other) → bool
inherited
importStatement(String path, {bool includeIgnores = false, ImportStyle style = ImportStyle.granular, BarrelImportCache barrelCache = const BarrelImportCache.empty()}) → String?
includeIgnores will add any ignore comments to above any show combinator
inherited
join(Reference ref) → Reference
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolvedImportUri(String path, {ImportStyle style = ImportStyle.granular, BarrelImportCache barrelCache = const BarrelImportCache.empty()}) → String?
Resolves the import URI used for grouping and writing import statements.
inherited
showCombinator({bool includeIgnores = false}) → String?
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override