ProcessDetails class

Constructors

ProcessDetails({required Stream<List<int>> stdout, required Stream<List<int>> stderr, required int pid, required Future<int> exitCode})
const

Properties

exitCode → Future<int>
final
hashCode → int
The hash code for this object.
no setterinherited
pid → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stderr → Stream<List<int>>
final
stdout → Stream<List<int>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited