Reference class

Mixed-in types
Implementers

Constructors

Reference({required LibraryElement lib, required Element associatedElement, String? prefix})
const
Reference.optional({required LibraryElement lib, String? prefix, bool hide = false, Element? associatedElement})
const

Properties

associatedElement → Element?
final
hashCode → int
The hash code for this object.
no setterinherited
hide → bool
Whether to hide the reference from the import statement
final
hideCombinator → String?
no setterinherited
ignores → List<String>?
no setteroverride
import → Import
no setteroverride
lib → LibraryElement
final
optional → bool
final
prefix → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canInclude(ResolvedReferences import) → bool
canJoin(Reference other) → bool
inherited
importStatement(String path, {bool includeIgnores = false, ImportStyle style = ImportStyle.granular, BarrelImportCache barrelCache = const BarrelImportCache.empty()}) → String?
includeIgnores will add any ignore comments to above any show combinator
inherited
join(Reference ref) → Reference
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolvedImportUri(String path, {ImportStyle style = ImportStyle.granular, BarrelImportCache barrelCache = const BarrelImportCache.empty()}) → String?
Resolves the import URI used for grouping and writing import statements.
inherited
showCombinator({bool includeIgnores = false}) → String?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited