SoberCommand class
- Inheritance
-
- Object
- FixCommand
- SoberCommand
Constructors
- SoberCommand({required Args args})
Properties
- args → Args
-
finalinherited
- config → Config
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → ImportStyle
-
finalinherited
Methods
-
getParts(
ParsedUnitResult parsed) → List< String> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
List< String> files) → Future<int> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateImportStatements(
ResolvedReferences import, {Config? config, BarrelImportCache barrelCache = const BarrelImportCache.empty()}) → Future< void> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited