BarrelImportCache class
Resolves granular package imports to barrel exports that re-export the referenced element.
Constructors
-
BarrelImportCache({Map<
(String, String), String> ? lookup}) -
const
- BarrelImportCache.empty()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
String packageUri, Element? element) → String? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
build(
{required Iterable< Reference> references, required PackageConfig? packageConfig, required AnalysisSession session}) → Future<BarrelImportCache> -
exportsElement(
LibraryElement barrel, Element element, String name) → bool -
Whether
barrelre-exportselementundername.