SharedReference mixin
- Mixin applications
Properties
- associatedElement → Element?
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- hide → bool
-
no setter
- hideCombinator → String?
-
no setter
-
ignores
→ List<
String> ? -
no setter
- import → Import
-
no setter
- lib → LibraryElement
-
no setter
- optional → bool
-
no setter
- prefix → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
canJoin(
Reference other) → bool -
importStatement(
String path, {bool includeIgnores = false, ImportStyle style = ImportStyle.granular, BarrelImportCache barrelCache = const BarrelImportCache.empty()}) → String? -
includeIgnoreswill add any ignore comments to above anyshowcombinator -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolvedImportUri(
String path, {ImportStyle style = ImportStyle.granular, BarrelImportCache barrelCache = const BarrelImportCache.empty()}) → String? - Resolves the import URI used for grouping and writing import statements.
-
showCombinator(
{bool includeIgnores = false}) → String? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override